@@ -15,12 +15,14 @@ extern void F77_NAME(master)(double *, double *, double *, int *, int *,
                              int *, int *, double *, double *, int *,
                              double *, double *, int *, double *, int *);
 extern void F77_NAME(mnnd)(double *, double *, int *, double *, double *);
+extern void F77_NAME(cross)(double *, double *, int *, double *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"binsrt", (DL_FUNC) &F77_NAME(binsrt), 10},
     {"intri",  (DL_FUNC) &F77_NAME(intri),   6},
     {"master", (DL_FUNC) &F77_NAME(master), 15},
     {"mnnd",   (DL_FUNC) &F77_NAME(mnnd),    5},
+    {"cross",  (DL_FUNC) &F77_NAME(cross),   4},
     {NULL, NULL, 0}
 };
 
